@@ -26,6 +26,7 @@ class EmploymentModel(Timelineable):
     extra_contents: Optional[Any] = None
     company_short_name: Optional[str] = None
     short_job_title: Optional[str] = None
+    hours_per_week: Optional[int] = None
 
     def __post_init__(self):
         if self.latex_contents is None:
@@ -37,11 +38,15 @@ class EmploymentModel(Timelineable):
             return self.end_date
         return datetime.datetime.now()
 
-    def to_pyexlatex_employment(self) -> lr.Employment:
+    def to_pyexlatex_employment(self, include_hours_per_week: bool = False) -> lr.Employment:
+        date_str = self.date_str
+        if include_hours_per_week and self.hours_per_week is not None:
+            date_str += f' ({self.hours_per_week} hours/wk)'
+
         return lr.Employment(
             self.latex_contents,
             self.company_name,
-            self.date_str,
+            date_str,
             self.job_title,
             self.location,
         )
@@ -51,11 +56,15 @@ class EmploymentModel(Timelineable):
 class AcademicEmploymentModel(EmploymentModel):
     courses_taught: Optional[Sequence[CourseModel]] = None
 
-    def to_pyexlatex_employment(self) -> AcademicEmployment:
+    def to_pyexlatex_employment(self, include_hours_per_week: bool = False) -> AcademicEmployment:
+        date_str = self.date_str
+        if include_hours_per_week and self.hours_per_week is not None:
+            date_str += f' ({self.hours_per_week} hours/wk)'
+
         return AcademicEmployment(
             self.latex_contents,
             self.company_name,
-            self.date_str,
+            date_str,
             self.job_title,
             self.location,
             self.courses_taught,
