@@ -10,6 +10,8 @@ EXCLUDED_SOFTWARE_PROJECTS = [
     'crypto-pricing',
     'dash_keyed_file_browser',
     'fin-model-course-projects',
+    'awesome-panel',
+    'awesome-panel-extensions',
 ]
 
 PROFESSIONAL_SOFTWARE_PROJECT_ORDER = [
