@@ -73,7 +73,9 @@ REPLACE_DESCRIPTIONS = {
 
 ADD_DESCRIPTIONS = {
     'py-ex-latex': ' All my papers, presentations, and even my CV are generated using py-ex-latex.',
-    'project-report': ' This package helped generate this list of software projects.'
+    'project-report': ' This package helped generate this list of software projects.',
+    'nick-derobertis-site': ' I designed and created the entire site from scratch besides the logo, '
+                            'and in the process also built an HTML component framework on top of Panel.'
 }
 
 REPLACE_URLS = {
@@ -132,6 +134,7 @@ IGNORE_DIRECTORIES = DEFAULT_IGNORE_PATHS + (
     'mendeley-python-sdk',
     'personal-budget',
     'semopy',
+    'venv',
 )
 
 YAML_OUT_PATH = str(pathlib.Path(__file__).parent / 'projects.yaml')
